@@ -1,11 +1,11 @@
-# $Id: TCP.pm 1994 2006-06-17 22:40:25Z rcaputo $
+# $Id: TCP.pm 2040 2006-08-13 00:51:32Z immute $
 
 package POE::Component::Client::TCP;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my($r)=(q$Revision: 1994 $=~/(\d+)/);sprintf"1.%04d",$r};
+$VERSION = do {my($r)=(q$Revision: 2040 $=~/(\d+)/);sprintf"1.%04d",$r};
 
 use Carp qw(carp croak);
 use Errno qw(ETIMEDOUT ECONNRESET);
@@ -573,15 +573,23 @@ POE::Component::Server::TCP will create IPv6 sockets.
 =item Filter
 
 Filter specifies the type of filter that will parse input from a
-server.  It may either be a scalar or a list reference.  If it is a
-scalar, it will contain a POE::Filter class name.  If it is a list
-reference, the first item in the list will be a POE::Filter class
-name, and the remaining items will be constructor parameters for the
-filter.  For example, this changes the line separator to a vertical
-pipe:
+server.  It may either be a scalar, a list reference or a POE::Filter
+reference.
+If it is a scalar, it will contain a POE::Filter class name.
+
+  Filter => "POE::Filter::Line",
+
+If it is a list reference, the first item in the list will be a 
+POE::Filter class name, and the remaining items will be constructor
+parameters for the filter.  For example, this changes the line separator
+to a vertical pipe:
 
   Filter => [ "POE::Filter::Line", Literal => "|" ],
 
+If it is an object, it will be clone()'d.
+
+  Filter => POE::Filter::Line->new()
+
 Filter is optional.  The component will supply a "POE::Filter::Line"
 instance none is specified.  If you supply a different value for
 Filter, then you must also C<use> that filter class.
