@@ -6,7 +6,7 @@ use strict;
 use POE::Filter;
 
 use vars qw($VERSION @ISA);
-$VERSION = do {my@r=(q$Revision: 1.6 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my($r)=(q$Revision: 1999 $=~/(\d+)/);sprintf"1.%04d",$r};
 @ISA = qw(POE::Filter);
 
 use Carp qw(croak);
@@ -25,7 +25,7 @@ sub new {
   my %params = @_;
 
   croak "BlockSize must be greater than 0" unless (
-    defined($params{BlockSize}) || ($params{BlockSize} < 1)
+    defined($params{BlockSize}) && ($params{BlockSize} > 0)
   );
 
   my $self = bless [
@@ -36,6 +36,17 @@ sub new {
   ], $type;
 }
 
+sub clone {
+  my $self = shift;
+  my $clone = bless [
+    $self->[0], # BLOCKSIZE
+    [],         # GETBUFFER
+    [],         # PUTBUFFER
+    $self->[3], # CHECKPUT
+  ], ref $self;
+  $clone;
+}
+
 #------------------------------------------------------------------------------
 # get() is inherited from POE::Filter.
 
@@ -66,7 +77,7 @@ sub put {
       push @{$self->[PUTBUFFER]}, @$_;
     }
     while (@{$self->[PUTBUFFER]} >= $self->[BLOCKSIZE]) {
-      push @result, splice @{$self->[GETBUFFER]}, 0, $self->[BLOCKSIZE];
+      push @result, splice @{$self->[PUTBUFFER]}, 0, $self->[BLOCKSIZE];
     }
   }
   else {
@@ -174,6 +185,20 @@ waiting to be sent.
 
 =item *
 
+POE::Filter::RecordBlock::blocksize
+
+The blocksize() method takes one optional parameter, the new blocksize.
+It returns the current blocksize.
+
+=item *
+
+POE::Filter::RecordBlock::checkput
+
+The checkput() method takes one optional parameter, the new state of the
+CheckPut flag.  It returns the current CheckPut flag.
+
+=item *
+
 See POE::Filter.
 
 =back
